@@ -1,8 +1,22 @@
 import os
-from typing import List, Union, Tuple
+from enum import Enum
+
+
+class FileMode(Enum):
+    READ = 'r'
+    WRITE = 'w',
+    APPEND = 'a',
+    READ_BYTES = 'rb',
+    WRITE_BYTES = 'wb',
+    APPEND_BYTES = 'ab',
+    READ_WRITE = 'r+',
+    READ_WRITE_BYTES = 'rb+',
+    WRITE_READ = 'w+',
+    WRITE_READ_BYTES = 'wb+',
+    APPEND_READ = 'a+',
+    APPEND_READ_BYTES = 'ab+'
 
 
-# Files #
 def split_file_path(file_path):
     return '/'.join(file_path.split('/')[:-1])
 
@@ -13,15 +27,15 @@ def make_path(file_path):
         os.makedirs(working_path)
 
 
-def write_to_file(text, filename, write_mode: str = "w+"):
+def write_to_file(text, filename, write_mode: FileMode = FileMode.WRITE_READ):
     make_path(filename)
-    f = open(filename, write_mode)
+    f = open(filename, write_mode.value)
     f.write(text)
     f.close()
 
 
-def read_from_file(filename, read_mode: str = 'r'):
-    with open(filename, read_mode) as f:
+def read_from_file(filename, read_mode: FileMode = FileMode.READ):
+    with open(filename, read_mode.value) as f:
         text = f.read()
     return text
 
